You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@sling.apache.org by ro...@apache.org on 2022/03/18 15:57:27 UTC

[sling-tooling-release] branch master updated (bcebbc0 -> 4a3edba)

This is an automated email from the ASF dual-hosted git repository.

rombert pushed a change to branch master
in repository https://gitbox.apache.org/repos/asf/sling-tooling-release.git.


    from bcebbc0  SLING-11051 - Fixing JavaDoc badge
     new 482a72b  SLING-11163 - Update generate_javadoc_for_release.sh to work on the feature model
     new 4a3edba  SLING-11163 - Update generate_javadoc_for_release.sh to work on the feature model

The 2 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.


Summary of changes:
 generate_javadoc_for_release.sh | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

[sling-tooling-release] 01/02: SLING-11163 - Update generate_javadoc_for_release.sh to work on the feature model

Posted by ro...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

rombert pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/sling-tooling-release.git

commit 482a72b0c3d6324da31154e528bcf5a6396aa5be
Author: Robert Munteanu <ro...@apache.org>
AuthorDate: Fri Mar 18 16:43:18 2022 +0100

    SLING-11163 - Update generate_javadoc_for_release.sh to work on the feature model
    
    Read bundle information from the feature model
---
 generate_javadoc_for_release.sh | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)

diff --git a/generate_javadoc_for_release.sh b/generate_javadoc_for_release.sh
index 87388bc..8cacbcd 100755
--- a/generate_javadoc_for_release.sh
+++ b/generate_javadoc_for_release.sh
@@ -112,7 +112,7 @@ pushd $WORKDIR
 # This might fail due to duplications in the classpath (see https://issues.apache.org/jira/browse/SLING-6766?focusedCommentId=16358298&page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel#comment-16358298)
 # The classpath order is unfortunately not predictable with m-j-p 3.0.0 (https://issues.apache.org/jira/browse/MJAVADOC-513)
 mvn -DexcludePackageNames="*.impl:*.internal:*.jsp:sun.misc:*.juli:*.testservices:*.integrationtest:*.maven:javax.*:org.osgi.*" \
-         org.apache.maven.plugins:maven-javadoc-plugin:3.0.0:aggregate -Dnotimestamp=true
+         org.apache.maven.plugins:maven-javadoc-plugin:3.0.0:aggregate -Dnotimestamp=true -Dignore.javadocjdk=true
 popd
 
 echo "Generated Javadocs can be found in $WORKDIR/target/site/apidocs/"
diff --git a/generate_javadoc_for_release.sh b/generate_javadoc_for_release.sh
index 445926e..87388bc 100755
--- a/generate_javadoc_for_release.sh
+++ b/generate_javadoc_for_release.sh
@@ -1,6 +1,6 @@
 #!/bin/bash -e
 
-VERSION=11
+VERSION=12
 WORKDIR=out
 ALLOW_SNAPSHOT=0
 
@@ -10,15 +10,15 @@ if [ ! -d $WORKDIR ] ; then
 fi
 
 # get bundle list
-if [ -f $WORKDIR/slingfeature.txt ] ; then
-    echo "slingfeature.txt already present, not downloading";
+if [ -f $WORKDIR/feature.json ] ; then
+    echo "feature.json already present, not downloading";
 else
-    echo "Downloading bundle list for Sling $VERSION"
-    wget https://repo1.maven.org/maven2/org/apache/sling/org.apache.sling.starter/$VERSION/org.apache.sling.starter-$VERSION-slingfeature.txt -O $WORKDIR/slingfeature.txt
+    echo "Downloading bundle list for Sling $VERSION (oak-tar variant)"
+    wget  https://repo1.maven.org/maven2/org/apache/sling/org.apache.sling.starter/$VERSION/org.apache.sling.starter-$VERSION-oak_tar.slingosgifeature -O $WORKDIR/feature.json
 fi
 
-# extract <artifactId>-<version> from slingfeature.txt
-artifacts=$(awk -F '/' '/org.apache.sling\// { print $2 ":" $3 }' < $WORKDIR/slingfeature.txt)
+# extract <artifactId>-<version> from feature file
+artifacts=$(cat $WORKDIR/feature.json | jq -r '.bundles[].id | select(startswith("org.apache.sling"))' | awk -F ':' '{ print $2 ":" $3 }')
 
 # add additional artifacts which are not part of the launchpad
 # https://issues.apache.org/jira/browse/SLING-6766

[sling-tooling-release] 02/02: SLING-11163 - Update generate_javadoc_for_release.sh to work on the feature model

Posted by ro...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

rombert pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/sling-tooling-release.git

commit 4a3edbae395b1a9f9afb82f818784712226cb3ae
Author: Robert Munteanu <ro...@apache.org>
AuthorDate: Fri Mar 18 16:56:09 2022 +0100

    SLING-11163 - Update generate_javadoc_for_release.sh to work on the feature model
    
    Allow building the API Javadocs with Java 8, this has worked fine for me.
---
 generate_javadoc_for_release.sh | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)
